# WARPY

**Warpy** is a command-line program to get [WARP+](https://blog.cloudflare.com/announcing-warp-plus/) as [WireGuard](https://www.wireguard.com/) configuration

>It requires the Python interpreter, version 3.5+, and it is not platform specific. It should work on your Unix box, on Windows or on macOS. 
## INSTALLATION
To install it right away for all UNIX users (Linux, macOS, etc.), type:

    pip3 install warpy
   
## How to use
By using this, you agree the [Privacy Policy](https://www.cloudflare.com/application/privacypolicy/) and [Terms of Service](https://www.cloudflare.com/application/terms/) of Cloudflare 1.1.1.1

To run **warpy**, simply execute
    `python3 -m warpy` or `warpy` in your terminal.

## FAQ

### How does `warpy` get WARP+ quota for free?

It currently get quota by faking referrers since there is no way to pay for premium version outside of 1.1.1.1 app, but it is recommended to pay for it on your phone if you think their service is good.
